<template>
  <win-md :title="setting.title" @close="close" :width="'800px'">
    <el-form ref="ruleForm" :model="formData" :rules="rules" class="demo-ruleForm" label-width="100px">
      <el-row :gutter="24">
        <el-col :span="12">
          <el-form-item label="物品分类" prop="code">
            <el-input disabled v-model="formData.code" clearable maxlength="20" show-word-limit style="width: 100%" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="物品名称" prop="name">
            <el-input v-model="formData.name" clearable maxlength="20" show-word-limit style="width: 100%" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="24">
        <el-col :span="12">
          <el-form-item label="规格型号">
            <el-input v-model="formData.adss" clearable maxlength="20" show-word-limit style="width: 100%" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-table :data="formData.models" :stripe="true">
        <el-table-column prop="baseGoodsModelsId" label="规格型号" align="center"> </el-table-column>
        <el-table-column prop="baseGoodsModelsId" label="保底库存" align="center">
          <template slot-scope="scope">
            <el-input v-model="scope.row.baseGoodsModelsId"></el-input>
          </template>
        </el-table-column>
        <el-table-column prop="baseGoodsModelsId" label="封顶库存" align="center">
          <template slot-scope="scope">
            <el-input v-model="scope.row.baseGoodsModelsId"></el-input>
          </template>
        </el-table-column>
      </el-table>
    </el-form>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close" />
      <my-button name="保存" site="form" @click="save" />
    </div>
  </win-md>
</template>

<script>
import winMd from '@/components/win/win-md';
import myButton from '@/components/myButton/myButton';
import * as finsystenant from '@/api/baseSetting/finsystenant';

export default {
  components: { winMd, myButton },
  props: {
    setting: {
      type: Object,
      default: () => {},
    },
  },
  data() {
    return {
      checkAll: false,
      checkedList: [],
      formData: {
        baseCategoryIds: '', // 分类编号数组
        baseCategoryId: '', // 分类编号
        baseGoodsTemplateId: '', // 物品模版编号
        modelsIds: [], //规格型号
        models:[]
      },
      modelsItem: {
        baseGoodsModelsId: '', // 规格型号编号
        worehouseCount: 0,
        counts: 0, // 操作数量
      },
      rules: {
        code: [{ required: true, message: '请输入机构编号', trigger: 'blur' }],
        name: [{ required: true, message: '请输入机构名称', trigger: 'blur' }],
        status: [{ required: true, message: '请选择状态', trigger: 'blur' }],
      },
    };
  },
  created() {
    if (this.setting.info) {
      this.formData = Object.assign({}, JSON.parse(this.setting.info));
    }
  },
  methods: {
    getEditInfo(id) {},
    close() {
      this.$emit('close');
    },
    save() {
      this.$refs.ruleForm.validate((valid) => {
        if (valid) {
          const params = Object.assign({}, this.formData);
          if (this.setting.id) {
            // 编辑接口
            finsystenant.edit(params).then((res) => {
              if (res) {
                this.$message.success('保存成功！');
                this.close();
                this.$emit('search');
              } else {
                this.$message.error('保存失败');
              }
            });
          } else {
            params.orgId = this.setting.orgId;
            finsystenant.add(params).then((res) => {
              if (res) {
                this.$message.success('保存成功！');
                this.close();
                this.$emit('search');
              } else {
                this.$message.error('保存失败');
              }
            });
          }
        } else {
          this.$message.error('校验未通过，请检查。');
        }
      });
    },
  },
};
</script>
